@@ -6,6 +6,6 @@ TSZ = TIMESTAMP(timezone=True)
 def common_columns():
     return [
         Column("id"        , Integer , primary_key=True, autoincrement=True),
-        Column("created_at", TSZ     , index=True, default=func.current_timestamp()),
-        Column("updated_at", TSZ     , index=True, default=func.current_timestamp(), onupdate=func.current_timestamp()),
+        Column("created_at", TSZ     , index=True, server_default=func.current_timestamp()),
+        Column("updated_at", TSZ     , index=True, server_default=func.current_timestamp(), onupdate=func.current_timestamp()),
     ]
